Tokenizing is the process of converting a tree-like structure
into a single [TokenStream], usually representing
an instantiated Bundle of the structure.
Structs
- Tokenize
Related - For a given
RelationshipTargetcomponent,
Functions
- is_
event - Events are any attribute keys that start with
on, and the value is not a string literal. This is to allow verbatim js handlers likeonclick="some_js_function()". - tokenize_
bundle - Create a
TokenStreamof aBundlethat represents the finalized tree of nodes for the givenEntity, as opposed to the tokenized tree, seetokenize_bundle_tokens. - tokenize_
bundle_ tokens - Create a
TokenStreamof aBundlethat represents the tokenized tree of nodes for the givenEntity, as opposed to the finalized tree, - tokenize_
bundle_ with_ errors - Calls
tokenize_bundleand appends any diagnostics tokens like rstml compile errors. Prefer this method for macros, andtokenize_bundlefor codegen. - tokenize_
combinator - Parse combinator string into a finalized
InstanceRoot, seetokenize_bundle. - tokenize_
combinator_ tokens - Parse combinator string into a tokenized
InstanceRoot, seetokenize_bundle_tokens. - tokenize_
element_ attributes - tokenize_
event_ handler - tokenize_
related - If the entity has this
RelationshipTarget, then map each child withmap_childand return arelated!TokenStream - tokenize_
roots - tokenize_
rstml - Parse rstml tokens into a finalized
InstanceRoot, seetokenize_bundle. - tokenize_
rstml_ tokens - Parse rstml tokens into a tokenized
InstanceRoot, seetokenize_bundle_tokens. - tokenize_
rsx_ directives - tokenize_
rsx_ nodes - tokenize_
template - tokenize_
web_ directives - tokenize_
web_ nodes - unbounded_
bundle - Uses Tuple if the number of items items can be represented as a tuple,
otherwise use
OnSpawn - unbounded_
related - Uses
related!if the number of related items can be represented as a tuple, otherwise usespawn_with